Input/output
============

.. automodule:: tamkin.io
   :members:

Tools to read data from general packages
----------------------------------------

CHARMM
~~~~~~

.. automodule:: tamkin.io.charmm
   :members:

CP2K
~~~~

.. automodule:: tamkin.io.cp2k
   :members:

CPMD
~~~~

.. automodule:: tamkin.io.cpmd
   :members:

Gaussian 03/09
~~~~~~~~~~~~~~

.. automodule:: tamkin.io.gaussian
   :members:

QChem
~~~~~

.. automodule:: tamkin.io.qchem
   :members:

VASP
~~~~

.. automodule:: tamkin.io.vasp
   :members:


File formats specific for TAMkin
---------------------------------

.. automodule:: tamkin.io.internal
   :members:

Tools to generate trajectories
------------------------------

.. automodule:: tamkin.io.trajectory
   :members:
